@@ -3,15 +3,15 @@ from os.path import join
 from gettext import gettext as _
 from colorblind.defs import VERSION
 from colorblind.Utils import load_icon
-import gtk, gtk.gdk, gnomevfs, gobject
+import gtk, gtk.gdk, gobject
 import colorblind
 
 
 def on_email(about, mail):
-	gnomevfs.url_show("mailto:%s" % mail)
+	gtk.show_uri(None, "mailto:%s" % mail, 0)
 
 def on_url(about, link):
-	gnomevfs.url_show(link)
+	gtk.show_uri(None, link, 0)
 
 gtk.about_dialog_set_email_hook(on_email)
 gtk.about_dialog_set_url_hook(on_url)
