@@ -2,7 +2,7 @@ from gettext import gettext as _
 from os.path import join, isdir
 import os
 import struct
-import gtk, gtk.gdk, gtk.glade, gobject, gconf
+import gtk, gtk.gdk, gobject, gconf
 import colorblind, colorblind.Utils, colorblind.ColorblindApplet
 
 MAXINT = 2 ** ((8 * struct.calcsize('i')) - 1) - 1
@@ -154,7 +154,7 @@ class AccelEntry( gobject.GObject ):
 				gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_MODAL,
 				gtk.MESSAGE_WARNING,
 				gtk.BUTTONS_CANCEL,
-				_("The shortcut \"%s\" cannot be used because it will become unusable to type using this key.\nPlease try with a key such as Control, Alt or Shift at the same time.\n")
+				_("The shortcut \"%s\" cannot be used because it will become impossible to type using this key.\nPlease try with a key such as Control, Alt or Shift at the same time.\n")
 				% gtk.accelerator_name(accel_keyval, accel_mods)
 			)
 			dialog.run()
@@ -195,18 +195,19 @@ class ColorblindPreferencesUI:
 	CB_FILTER_NO_FILTER, CB_FILTER_SELECTIVE_SATURATE_RED, CB_FILTER_SELECTIVE_SATURATE_GREEN, CB_FILTER_SELECTIVE_SATURATE_BLUE, CB_FILTER_SELECTIVE_DESATURATE_RED, CB_FILTER_SELECTIVE_DESATURATE_GREEN, CB_FILTER_SELECTIVE_DESATURATE_BLUE, CB_FILTER_POSITIVE_HUE_SHIFT, CB_FILTER_NEGATIVE_HUE_SHIFT = range (9)
 
 	def __init__(self, applet):
-		self.glade = gtk.glade.XML(join(colorblind.SHARED_DATA_DIR, "colorblind-prefs.glade"))
+		self.ui = gtk.Builder()
+		self.ui.add_from_file(join(colorblind.SHARED_DATA_DIR, "colorblind-prefs.ui"))
 
-		self.dialog = self.glade.get_widget("window_preferences")
-		self.radio1 = self.glade.get_widget("radio_filter_red_saturate")
-		self.radio2 = self.glade.get_widget("radio_filter_green_saturate")
-		self.radio3 = self.glade.get_widget("radio_filter_blue_saturate")
-		self.radio4 = self.glade.get_widget("radio_filter_red_desaturate")
-		self.radio5 = self.glade.get_widget("radio_filter_green_desaturate")
-		self.radio6 = self.glade.get_widget("radio_filter_blue_desaturate")
-		self.radio7 = self.glade.get_widget("radio_filter_positive_hue_shift")
-		self.radio8 = self.glade.get_widget("radio_filter_negative_hue_shift")
-		self.hbox_default = self.glade.get_widget("hbox_default")
+		self.dialog = self.ui.get_object("window_preferences")
+		self.radio1 = self.ui.get_object("radio_filter_red_saturate")
+		self.radio2 = self.ui.get_object("radio_filter_green_saturate")
+		self.radio3 = self.ui.get_object("radio_filter_blue_saturate")
+		self.radio4 = self.ui.get_object("radio_filter_red_desaturate")
+		self.radio5 = self.ui.get_object("radio_filter_green_desaturate")
+		self.radio6 = self.ui.get_object("radio_filter_blue_desaturate")
+		self.radio7 = self.ui.get_object("radio_filter_positive_hue_shift")
+		self.radio8 = self.ui.get_object("radio_filter_negative_hue_shift")
+		self.hbox_default = self.ui.get_object("hbox_default")
 		self.combofilters = gtk.combo_box_new_text ()
 		self.hbox_default.add (self.combofilters)
 		self.combofilters.append_text (_("Selective Red Saturation"))
@@ -217,19 +218,19 @@ class ColorblindPreferencesUI:
 		self.combofilters.append_text (_("Selective Blue Desaturation"))
 		self.combofilters.append_text (_("Positive Hue Shift"))
 		self.combofilters.append_text (_("Negative Hue Shift"))
-		self.check_default_filter = self.glade.get_widget("check_default_filter")
-		self.button_close = self.glade.get_widget("button_close")
+		self.check_default_filter = self.ui.get_object("check_default_filter")
+		self.button_close = self.ui.get_object("button_close")
 		
 		# Retreive current values
 		self.keybinding_on_off = colorblind.GCONF_CLIENT.get_string(applet.prefs.GCONF_KEYBINDING_ONOFF)
 		self.keyboard_shortcut_entry_on_off = AccelEntry("<Shift><Control>c", self)
 		self.keyboard_shortcut_entry_on_off.connect('accel-edited', self.on_keyboard_shortcut_entry_changed, colorblind.GCONF_KEYBINDING_ONOFF)
-		self.glade.get_widget("table_shortcut").attach(self.keyboard_shortcut_entry_on_off.get_widget(), 1, 2, 0, 1)
+		self.ui.get_object("table_shortcut").attach(self.keyboard_shortcut_entry_on_off.get_widget(), 1, 2, 0, 1)
 
 		self.keybinding_switch = colorblind.GCONF_CLIENT.get_string(applet.prefs.GCONF_KEYBINDING_SWITCH)
 		self.keyboard_shortcut_entry_switch = AccelEntry("<Shift><Control>n", self)
 		self.keyboard_shortcut_entry_switch.connect('accel-edited', self.on_keyboard_shortcut_entry_changed, colorblind.GCONF_KEYBINDING_SWITCH)
-		self.glade.get_widget("table_shortcut").attach(self.keyboard_shortcut_entry_switch.get_widget(), 1, 2, 1, 2)
+		self.ui.get_object("table_shortcut").attach(self.keyboard_shortcut_entry_switch.get_widget(), 1, 2, 1, 2)
 
 		colorblind.GCONF_CLIENT.notify_add (colorblind.GCONF_COLORBLIND_FILTER, self.sync_ui)
 		self.colorblind_filter = colorblind.GCONF_CLIENT.get_int(colorblind.GCONF_COLORBLIND_FILTER)
