@@ -23,12 +23,9 @@
 #ifndef MAGNIFIER_PRIVATE_H_
 #define MAGNIFIER_PRIVATE_H_
 
+G_BEGIN_DECLS
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 struct _MagnifierPrivate {
 	GtkWidget *w;
@@ -49,8 +46,6 @@ struct _MagnifierPrivate {
         GHashTable *cursorlist;
 };
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* MAGNIFIER_PRIVATE_H_ */
